==> discord-slider-1.1.1.tgz: package/index.js <==
const { Structures } = require("discord.js");

module.exports = (client) => {
    const disbut = require("discord-buttons")(client);

    class TextChannel extends Structures.get("TextChannel") {
        async createSlider(userID, embeds) {

            const button_back = new disbut.MessageButton()
                .setStyle('gray')
                .setID('back')
                .setLabel("<<");

            const button_next = new disbut.MessageButton()
                .setStyle('gray')
                .setID('next')
                .setLabel('>>');

            const button_back_disabled = new disbut.MessageButton()
                .setStyle('gray')
                .setID('back_disabled')
                .setLabel("<<")
                .setDisabled();

            const button_next_disabled = new disbut.MessageButton()
                .setStyle('gray')
                .setID('next_disabled')
                .setLabel('>>')
                .setDisabled();

            const buttonsActive = [button_back, button_next];

            const buttonsDisabled = [button_back_disabled, button_next_disabled];

            this.send({ embed: embeds[0], buttons: buttonsActive }).then(msg => {
                const collector = msg.createButtonCollector((button) => userID === userID, { time: 300000 });
        
                let currentPage = 0;
            
                collector.on('collect', button => {
                    button.defer();

                    if (button.clicker.user.id == userID) {
                        if (button.id == "back") {
                            if (currentPage !== 0) {
                                --currentPage;
                                msg.edit({embed:embeds[currentPage], buttons: buttonsActive});
                            } else {
                                currentPage = embeds.length - 1
                                msg.edit({embed:embeds[currentPage], buttons: buttonsActive});
                            };
                        }
    
                        else if (button.id == "next"){
                            if (currentPage < embeds.length - 1) {
                                currentPage++;
                                msg.edit({embed:embeds[currentPage], buttons: buttonsActive});
                            } else {
                                currentPage = 0
                                msg.edit({embed:embeds[currentPage], buttons: buttonsActive});
                            };
                        };
                    };
                });
                collector.on('end', collected => {
                    msg.edit({ embed: embeds[0], buttons: buttonsDisabled })
                });
                collector.on("error", (e) => console.log(e))
            })
        }
    };

    Structures.extend("TextChannel", () => TextChannel);
}

==> discord-slider-1.1.4.tgz: package/index.js <==
const { Structures } = require("discord.js");

module.exports = (client) => {
    const { MessageButton } = require("discord-buttons")

    class TextChannel extends Structures.get("TextChannel") {
        async createSlider(userID, embeds) {

            const button_back = new MessageButton()
                .setStyle('gray')
                .setID('back')
                .setLabel("<<");

            const button_next = new MessageButton()
                .setStyle('gray')
                .setID('next')
                .setLabel('>>');

            const button_back_disabled = new MessageButton()
                .setStyle('gray')
                .setID('back_disabled')
                .setLabel("<<")
                .setDisabled();

            const button_next_disabled = new MessageButton()
                .setStyle('gray')
                .setID('next_disabled')
                .setLabel('>>')
                .setDisabled();

            const buttonsActive = [button_back, button_next];

            const buttonsDisabled = [button_back_disabled, button_next_disabled];

            this.send({ embed: embeds[0], buttons: buttonsActive }).then(msg => {
                const collector = msg.createButtonCollector((button) => userID === userID, { time: 300000 });
        
                let currentPage = 0;
            
                collector.on('collect', button => {
                    button.defer();

                    if (button.clicker.user.id == userID) {
                        if (button.id == "back") {
                            if (currentPage !== 0) {
                                --currentPage;
                                msg.edit({embed:embeds[currentPage], buttons: buttonsActive});
                            } else {
                                currentPage = embeds.length - 1
                                msg.edit({embed:embeds[currentPage], buttons: buttonsActive});
                            };
                        }
    
                        else if (button.id == "next"){
                            if (currentPage < embeds.length - 1) {
                                currentPage++;
                                msg.edit({embed:embeds[currentPage], buttons: buttonsActive});
                            } else {
                                currentPage = 0
                                msg.edit({embed:embeds[currentPage], buttons: buttonsActive});
                            };
                        };
                    };
                });
                collector.on('end', collected => {
                    msg.edit({ embed: embeds[0], buttons: buttonsDisabled })
                });
                collector.on("error", (e) => console.log(e))
            })
        }
    };

    Structures.extend("TextChannel", () => TextChannel);
}
